@@ -1,15 +1,21 @@
 #' @export
-#' @title add object into a new shape
-#' @description add object into a new shape in a slide.
-#' @param x a pptx device
-#' @param value object to add as a new shape.
-#' @param location a placeholder location object. This is a convenient
-#' argument that can replace usage of arguments \code{type} and \code{index}.
-#' See section \code{see also}.
+#' @title add objects into a new shape on the current slide
+#' @description add object into a new shape in the current slide. This
+#' function is able to add all supported outputs to a presentation
+#' and should replace calls to older functions starting with
+#' \code{ph_with_*}.
+#' @param x an rpptx object
+#' @param value object to add as a new shape. Supported objects
+#' are vectors, data.frame, graphics, block of formatted paragraphs,
+#' unordered list of formatted paragraphs,
+#' pretty tables with package flextable, editable graphics with
+#' package rvg, 'Microsoft' charts with package mschart.
+#' @param location a placeholder location object.
+#' It will be used to specify the location of the new shape. This location
+#' can be defined with a call to one of the ph_location functions. See
+#' section \code{see also}.
 #' @param ... Arguments to be passed to methods
 #' @examples
-#' library(magrittr)
-#'
 #' fileout <- tempfile(fileext = ".pptx")
 #' doc <- read_pptx()
 #' doc <- add_slide(doc, layout = "Two Content",
@@ -20,14 +26,15 @@
 #'                location = ph_location_right() )
 #'
 #' if( require("ggplot2") ){
-#'   doc <- add_slide(doc, layout = "Title and Content",
-#'     master = "Office Theme")
+#'   doc <- add_slide(doc)
 #'   gg_plot <- ggplot(data = iris ) +
 #'     geom_point(mapping = aes(Sepal.Length, Petal.Length),
 #'       size = 3) +
 #'     theme_minimal()
 #'   doc <- ph_with(x = doc, value = gg_plot,
 #'                  location = ph_location_fullsize() )
+#'   doc <- ph_with(x = doc, value = "graphic title",
+#'                location = ph_location_type(type="title") )
 #' }
 #'
 #' doc <- add_slide(doc, layout = "Title and Content",
@@ -42,27 +49,52 @@
 #'     location = ph_location_left(),
 #'     use_loc_size = TRUE )
 #' }
+#' # block list ------
+#' bl <- block_list(
+#'   fpar(ftext("hello world", shortcuts$fp_bold(color = "pink"))),
+#'   fpar(
+#'     ftext("hello", shortcuts$fp_bold()),
+#'     ftext("hello", shortcuts$fp_italic(color="red"))
+#'   ))
+#' doc <- add_slide(doc)
+#' doc <- ph_with(x = doc, value = bl,
+#'                location = ph_location_type(type="body") )
 #'
-#'
-#'
+#' # fpar ------
+#' hw <- fpar(ftext("hello world", shortcuts$fp_bold(color = "pink")))
+#' doc <- add_slide(doc)
+#' doc <- ph_with(x = doc, value = hw,
+#'                location = ph_location_type(type="body") )
+
+
 #' # unordered_list ----
 #' ul <- unordered_list(
 #'   level_list = c(1, 2, 2, 3, 3, 1),
 #'   str_list = c("Level1", "Level2", "Level2", "Level3", "Level3", "Level1"),
 #'   style = fp_text(color = "red", font.size = 0) )
-#' doc <- add_slide(doc, layout = "Title and Content",
-#'                  master = "Office Theme")
+#' doc <- add_slide(doc)
 #' doc <- ph_with(x = doc, value = ul,
 #'                location = ph_location_fullsize() )
 #'
 #' print(doc, target = fileout )
 #' @seealso [ph_location_type], [ph_location], [ph_location_label],
-#' [ph_location_left], [ph_location_right], [ph_location_fullsize]
-#' @importFrom rlang eval_tidy enquo call_modify
+#' [ph_location_left], [ph_location_right], [ph_location_fullsize],
+#' [ph_location_template]
+#' @importFrom rlang eval_tidy
 ph_with <- function(x, value, ...){
   UseMethod("ph_with", value)
 }
 
+gen_bg_str <- function(bg){
+  bg_str <- ""
+  if( !is.null(bg)){
+    bg_str <- sprintf("%s<a:srgbClr val=\"%s\"><a:alpha val=\"%.0f\"/></a:srgbClr></a:solidFill>",
+                      pml_with_ns("a:solidFill") , colcode0(bg), colalpha(bg) )
+  }
+  bg_str
+}
+
+
 gen_ph_str <- function( left = 0, top = 0, width = 3, height = 3,
                 bg = "transparent", rot = 0, label = "", ph = "<p:ph/>"){
 
@@ -71,86 +103,45 @@ gen_ph_str <- function( left = 0, top = 0, width = 3, height = 3,
   if( !is.null(bg) && !is.color( bg ) )
     stop("bg must be a valid color.", call. = FALSE )
 
-  bg_str <- ""
-  if( !is.null(bg)){
-    bg_str <- sprintf("<a:solidFill><a:srgbClr val=\"%s\"><a:alpha val=\"%.0f\"/></a:srgbClr></a:solidFill>",
-            colcode0(bg), colalpha(bg) )
-  }
-
-  if( is.na(ph)){
-    xfrm_str <- "<a:xfrm rot=\"%.0f\"><a:off x=\"%.0f\" y=\"%.0f\"/><a:ext cx=\"%.0f\" cy=\"%.0f\"/></a:xfrm>"
-    xfrm_str <- sprintf(xfrm_str, -rot * 60000,
-                        left * 914400, top * 914400,
-                        width * 914400, height * 914400)
-    ph = "<p:ph/>"
-  } else {
-    xfrm_str <- ""
-  }
-
-
-  str <- "<p:nvSpPr><p:cNvPr id=\"0\" name=\"%s\"/><p:cNvSpPr><a:spLocks noGrp=\"1\"/></p:cNvSpPr><p:nvPr>%s</p:nvPr></p:nvSpPr><p:spPr>%s%s</p:spPr>"
-  sprintf(str, label, ph, xfrm_str, bg_str )
-
-}
-gen_ph_str_old <- function( left = 0, top = 0, width = 3, height = 3,
-                bg = "transparent", rot = 0, label = "", ph = "<p:ph/>"){
-
-  if( is.null(rot)) rot <- 0
-
-  if( !is.null(bg) && !is.color( bg ) )
-    stop("bg must be a valid color.", call. = FALSE )
-
-  bg_str <- ""
-  if( !is.null(bg)){
-    bg_str <- sprintf("<a:solidFill><a:srgbClr val=\"%s\"><a:alpha val=\"%.0f\"/></a:srgbClr></a:solidFill>",
-            colcode0(bg), colalpha(bg) )
-  }
+  bg_str <- gen_bg_str(bg)
 
   xfrm_str <- "<a:xfrm rot=\"%.0f\"><a:off x=\"%.0f\" y=\"%.0f\"/><a:ext cx=\"%.0f\" cy=\"%.0f\"/></a:xfrm>"
   xfrm_str <- sprintf(xfrm_str, -rot * 60000,
                       left * 914400, top * 914400,
                       width * 914400, height * 914400)
+  if( is.null(ph) || is.na(ph)){
+    ph = "<p:ph/>"
+  }
 
 
   str <- "<p:nvSpPr><p:cNvPr id=\"0\" name=\"%s\"/><p:cNvSpPr><a:spLocks noGrp=\"1\"/></p:cNvSpPr><p:nvPr>%s</p:nvPr></p:nvSpPr><p:spPr>%s%s</p:spPr>"
   sprintf(str, label, ph, xfrm_str, bg_str )
 
 }
-
 #' @export
-#' @title eval a location on the current slide
-#' @description Eval a shape location against the current slide.
-#' This function is to be used to add custom openxml code.
-#' @param location a location for a placeholder. It has to be a
-#' quosure.
+#' @title Utility to eval a location
+#' @description Eval a shape location with fortify_location.
+#' This function will be removed in the next release; it was
+#' required when location was a quosure but this is no more
+#' necessary.
+#' @param location a location for a placeholder.
 #' @param x an rpptx object
-#' @examples
-#' library(rlang)
-#' doc <- read_pptx()
-#' doc <- add_slide(doc, layout = "Title and Content",
-#'   master = "Office Theme")
-#' location_eval(quo(ph_location_fullsize()), doc)
 #' @seealso \code{\link{ph_location}}, \code{\link{ph_with}}
 location_eval <- function(location, x){
-  slide <- x$slide$get_slide(x$cursor)
-  xfrm <- slide$get_xfrm()
-  location <- rlang::call_modify(location, x = x,
-                             layout = unique( xfrm$name ),
-                             master = unique(xfrm$master_name)
-  )
-  eval_tidy(location, data = x)
+  if(inherits(location, "quosure")){
+    fortify_location(eval_tidy(location), x)
+  } else {
+    fortify_location(location, x)
+  }
 }
 
 #' @export
-#' @section with character:
-#' When value is a character vector, each value will be
-#' added as a paragraph.
-#' @rdname ph_with
+#' @describeIn ph_with add a character vector to a new shape on the
+#' current slide, values will be added as paragraphs.
 ph_with.character <- function(x, value, location, ...){
   slide <- x$slide$get_slide(x$cursor)
 
-  location <- location_eval(rlang::enquo(location), x)
-
+  location <- fortify_location(location, doc = x)
   new_ph <- gen_ph_str(left = location$left, top = location$top,
                width = location$width, height = location$height,
                label = location$ph_label, ph = location$ph,
@@ -169,14 +160,13 @@ ph_with.character <- function(x, value, location, ...){
 
 #' @export
 #' @param format_fun format function for non character vectors
-#' @section with vector:
-#' When value is a vector, the values will be first formatted and
-#' then add as text, each value will be added as a paragraph.
-#' @rdname ph_with
+#' @describeIn ph_with add a numeric vector to a new shape on the
+#' current slide, values will be be first formatted then
+#' added as paragraphs.
 ph_with.numeric <- function(x, value, location, format_fun = format, ...){
   slide <- x$slide$get_slide(x$cursor)
   value <- format_fun(value, ...)
-  location <- location_eval(rlang::enquo(location), x)
+  location <- fortify_location(location, doc = x)
 
   new_ph <- gen_ph_str(left = location$left, top = location$top,
                width = location$width, height = location$height,
@@ -196,11 +186,13 @@ ph_with.numeric <- function(x, value, location, format_fun = format, ...){
 }
 
 #' @export
-#' @rdname ph_with
+#' @describeIn ph_with add a factor vector to a new shape on the
+#' current slide, values will be be converted as character and then
+#' added as paragraphs.
 ph_with.factor <- function(x, value, location, ...){
   slide <- x$slide$get_slide(x$cursor)
   value <- as.character(value)
-  location <- location_eval(rlang::enquo(location), x)
+  location <- fortify_location(location, doc = x)
 
   new_ph <- gen_ph_str(left = location$left, top = location$top,
                width = location$width, height = location$height,
@@ -223,14 +215,12 @@ ph_with.factor <- function(x, value, location, ...){
 ph_with.logical <- ph_with.numeric
 
 #' @export
-#' @section with block_list:
-#' When value is a block_list object, each value will be
-#' added as a paragraph.
-#' @rdname ph_with
+#' @describeIn ph_with add a \code{\link{block_list}} made
+#' of \code{\link{fpar}} to a new shape on the current slide.
 ph_with.block_list <- function(x, value, location, ...){
   slide <- x$slide$get_slide(x$cursor)
 
-  location <- location_eval(rlang::enquo(location), x)
+  location <- fortify_location(location, doc = x)
 
   pars <- sapply(value, format, type = "pml")
   pars <- paste0(pars, collapse = "")
@@ -253,13 +243,11 @@ ph_with.block_list <- function(x, value, location, ...){
 
 
 #' @export
-#' @section with unordered_list:
-#' When value is a unordered_list object, each value will be
-#' added as a paragraph.
-#' @rdname ph_with
+#' @describeIn ph_with add a \code{\link{unordered_list}} made
+#' of \code{\link{fpar}} to a new shape on the current slide.
 ph_with.unordered_list <- function(x, value, location, ...){
   slide <- x$slide$get_slide(x$cursor)
-  location <- location_eval(rlang::enquo(location), x)
+  location <- fortify_location(location, doc = x)
 
   if( !is.null(value$style)){
     style_str <- sapply(value$style, format, type = "pml")
@@ -288,17 +276,14 @@ ph_with.unordered_list <- function(x, value, location, ...){
 
 
 #' @export
-#' @section with data.frame:
-#' When value is a data.frame, a simple table
-#' is added, use package \code{flextable} instead
-#' for more advanced formattings.
 #' @param header display header if TRUE
 #' @param first_row,last_row,first_column,last_column logical for PowerPoint table options
-#' @rdname ph_with
+#' @describeIn ph_with add a data.frame to a new shape on the current slide. Use
+#' package \code{flextable} instead for more advanced formattings.
 ph_with.data.frame <- function(x, value, location, header = TRUE,
                                first_row = TRUE, first_column = FALSE,
                                last_row = FALSE, last_column = FALSE, ...){
-  location <- location_eval(rlang::enquo(location), x)
+  location <- fortify_location(location, doc = x)
 
   slide <- x$slide$get_slide(x$cursor)
   xml_elt <- table_shape(x = x, value = value, left = location$left*914400, top = location$top*914400,
@@ -307,21 +292,19 @@ ph_with.data.frame <- function(x, value, location, header = TRUE,
                          last_row = last_row, last_column = last_column,
                          header = header )
 
-  xml_add_child(xml_find_first(slide$get(), "//p:spTree"), as_xml_document(xml_elt))
+  value <- as_xml_document(xml_elt)
+  xml_to_slide(slide, location, value)
+  xml_add_child(xml_find_first(slide$get(), "//p:spTree"), value)
   slide$fortify_id()
   x
 }
 
 
 #' @export
-#' @section with a ggplot object:
-#' When value is a ggplot object, a raster plot
-#' is produced and added, use package \code{rvg}
-#' instead for more advanced graphical features.
-#' @rdname ph_with
+#' @describeIn ph_with add a ggplot object to a new shape on the
+#' current slide. Use package \code{rvg} for more advanced graphical features.
 ph_with.gg <- function(x, value, location, ...){
-  location <- location_eval(rlang::enquo(location), x)
-
+  location <- fortify_location(location, doc = x)
   slide <- x$slide$get_slide(x$cursor)
   if( !requireNamespace("ggplot2") )
     stop("package ggplot2 is required to use this function")
@@ -343,16 +326,9 @@ ph_with.gg <- function(x, value, location, ...){
   slide$reference_img(src = file, dir_name = file.path(x$package_dir, "ppt/media"))
   xml_elt <- fortify_pml_images(x, xml_elt)
 
-  doc <- as_xml_document(xml_elt)
-
-  node <- xml_find_first( doc, "p:spPr")
-  off <- xml_child(node, "a:xfrm/a:off")
-  xml_attr( off, "x") <- sprintf( "%.0f", location$left * 914400 )
-  xml_attr( off, "y") <- sprintf( "%.0f", location$top * 914400 )
-
-  xmlslide <- slide$get()
-
-  xml_add_child(xml_find_first(xmlslide, "p:cSld/p:spTree"), doc)
+  value <- as_xml_document(xml_elt)
+  xml_to_slide(slide, location, value)
+  xml_add_child(xml_find_first(slide$get(), "//p:spTree"), value)
   slide$fortify_id()
   x
 
@@ -360,27 +336,27 @@ ph_with.gg <- function(x, value, location, ...){
 
 
 #' @export
-#' @section with a external_img object:
-#' When value is a external_img object, image will be copied
-#' into the PowerPoint presentation. The width and height
-#' specified in call to \code{\link{external_img}} will be
-#' ignored, their values will be those of the location,
-#' unless use_loc_size is set to FALSE.
 #' @param use_loc_size if set to FALSE, external_img width and height will
 #' be used.
-#' @rdname ph_with
+#' @describeIn ph_with add a \code{\link{external_img}} to a new shape
+#' on the current slide.
+#'
+#' When value is a external_img object, image will be copied
+#' into the PowerPoint presentation. The width and height
+#' specified in call to \code{external_img} will be
+#' ignored, their values will be those of the location,
+#' unless use_loc_size is set to FALSE.
 ph_with.external_img <- function(x, value, location, use_loc_size = TRUE, ...){
-  location <- location_eval(rlang::enquo(location), x)
+  location <- fortify_location(location, doc = x)
 
   slide <- x$slide$get_slide(x$cursor)
 
-  if( use_loc_size ){
-    width <- location$width
-    height <- location$height
-  } else {
-    width <- attr(value, "dims")$width
-    height <- attr(value, "dims")$height
+  if( !use_loc_size ){
+    location$width <- attr(value, "dims")$width
+    location$height <- attr(value, "dims")$height
   }
+  width <- location$width
+  height <- location$height
 
   file_type <- gsub("(.*)(\\.[a-zA-Z0-0]+)$", "\\2", value)
 
@@ -402,16 +378,9 @@ ph_with.external_img <- function(x, value, location, use_loc_size = TRUE, ...){
   slide$reference_img(src = new_src, dir_name = file.path(x$package_dir, "ppt/media"))
   xml_elt <- fortify_pml_images(x, xml_elt)
 
-  doc <- as_xml_document(xml_elt)
-
-  node <- xml_find_first( doc, "p:spPr")
-  off <- xml_child(node, "a:xfrm/a:off")
-  xml_attr( off, "x") <- sprintf( "%.0f", location$left * 914400 )
-  xml_attr( off, "y") <- sprintf( "%.0f", location$top * 914400 )
-
-  xmlslide <- slide$get()
-
-  xml_add_child(xml_find_first(xmlslide, "p:cSld/p:spTree"), doc)
+  value <- as_xml_document(xml_elt)
+  xml_to_slide(slide, location, value)
+  xml_add_child(xml_find_first(slide$get(), "//p:spTree"), value)
   slide$fortify_id()
   x
 
@@ -421,34 +390,12 @@ ph_with.external_img <- function(x, value, location, use_loc_size = TRUE, ...){
 
 
 #' @export
-ph_with.fpar <- function( x, value, location,
-                          template_type = NULL, template_index = 1, ... ){
+#' @describeIn ph_with add an \code{\link{fpar}} to a new shape
+#' on the current slide as a single paragraph in a \code{\link{block_list}}.
+ph_with.fpar <- function( x, value, location, ... ){
 
-  location <- location_eval(rlang::enquo(location), x)
+  ph_with.block_list(x, value = block_list(value), location = location)
 
-  slide <- x$slide$get_slide(x$cursor)
-
-  new_ph <- gen_ph_str(left = location$left, top = location$top,
-               width = location$width, height = location$height, label = location$label,
-               rot = location$rotation, bg = location$bg, ph = location$ph)
-  new_ph <- paste0( pml_with_ns("p:sp"), new_ph,"</p:sp>")
-  if( !is.null( template_type ) ){
-    stopifnot( template_type %in% c("ctrTitle", "subTitle", "dt", "ftr", "sldNum", "title", "body") )
-    xfrm_df <- slide$get_xfrm(type = template_type, index = template_index)
-    new_ph <- gsub("<p:ph/>", xfrm_df$ph, new_ph)
-  }
-
-  new_node <- as_xml_document(new_ph)
-
-  p_ <- format( value, type = "pml")
-
-  simple_shape <- paste0( pml_with_ns("p:txBody"),
-                          "<a:bodyPr/><a:lstStyle/>",
-                          p_, "</p:txBody>")
-  xml_add_child(new_node, as_xml_document(simple_shape) )
-
-  xml_add_child(xml_find_first(slide$get(), "//p:spTree"), new_node)
-  slide$fortify_id()$save()
   x
 }
 
@@ -458,7 +405,9 @@ ph_with.fpar <- function( x, value, location,
 #' @export
 #' @title add a new empty shape
 #' @description add a new empty shape in the current slide.
-#' @param x a pptx device
+#' This function was implemented for development purpose and
+#' should not be used.
+#' @param x an pptx object
 #' @param location a placeholder location object. This is a convenient
 #' argument that can replace usage of arguments \code{type} and \code{index}.
 #' See [ph_location_type], [ph_location], [ph_location_label],
@@ -479,52 +428,96 @@ ph_with.fpar <- function( x, value, location,
 #' print(doc, target = fileout )
 #' @importFrom xml2 xml_find_first as_xml_document xml_remove
 ph_empty <- function( x, type = "body", index = 1, location = NULL ){
-
-  stopifnot( type %in% c("ctrTitle", "subTitle", "dt", "ftr", "sldNum", "title", "body") )
-  slide <- x$slide$get_slide(x$cursor)
-
-  if( !is.null( rlang::get_expr(rlang::enquo(location)) ) ){
-    location <- location_eval(rlang::enquo(location), x)
-  } else {
-    slide <- x$slide$get_slide(x$cursor)
-    sh_pr_df <- slide$get_location(type = type, index = index)
-    location <- ph_location(ph = sh_pr_df$ph, label = sh_pr_df$ph_label,
-                            left = sh_pr_df$left, top = sh_pr_df$top,
-                            width = sh_pr_df$width, height = sh_pr_df$height)
+  if( is.null( location ) ){
+    location <- ph_location_type(type = type, id = index)
   }
-
-  new_ph <- gen_ph_str(left = location$left, top = location$top,
-                       width = location$width, height = location$height,
-                       label = location$ph_label, ph = location$ph,
-                       rot = location$rotation, bg = location$bg)
-  xml_elt <- paste0( pml_with_ns("p:sp"), new_ph, "</p:sp>" )
+  new_ph <- gen_ph_str(left = 0, top = 0,
+                       width = 3, height = 3)
+  xml_elt <- paste0( pml_with_ns("p:sp"), new_ph,
+                     "<p:txBody><a:bodyPr/><a:lstStyle/></p:txBody></p:sp>" )
   node <- as_xml_document(xml_elt)
 
-  xml_add_child(xml_find_first(slide$get(), "//p:spTree"), node)
-  slide$fortify_id()
-  x
+  ph_with(x, node, location = location)
 }
 
+xml_to_slide <- function(slide, location, value){
+  node <- xml_find_first( value, as_xpath_content_sel("//") )
+  if(xml_name(node) == "grpSp"){
+    node_sppr <- xml_child(node, "p:grpSpPr")
+    node_xfrm <- xml_child(node, "p:grpSpPr/a:xfrm")
+    node_name <- xml_child(node, "p:nvGrpSpPr/p:cNvPr")
+  } else if(xml_name(node) == "graphicFrame") {
+    node_xfrm <- xml_child(node, "p:xfrm")
+    node_name <- xml_child(node, "p:nvGraphicFramePr/p:cNvPr")
+    node_sppr <- xml_missing()
+  } else if(xml_name(node) == "pic"){
+    node_sppr <- xml_child(node, "p:spPr")
+    node_xfrm <- xml_child(node, "p:spPr/a:xfrm")
+    node_name <- xml_child(node, "p:nvPicPr/p:cNvPr")
+  } else if(xml_name(node) == "sp"){
+    node_sppr <- xml_child(node, "p:spPr")
+    node_xfrm <- xml_child(node, "p:spPr/a:xfrm")
+    node_name <- xml_child(node, "p:nvSpPr/p:cNvPr")
+  } else {
+    node_xfrm <- xml_missing()
+    node_name <- xml_missing()
+    node_sppr <- xml_missing()
+  }
+
+
+  if( !inherits(node_name, "xml_missing") ){
+    xml_attr( node_name, "name") <- location$ph_label
+  }
+
+  if( !inherits(node_xfrm, "xml_missing") ){
+    off <- xml_child(node_xfrm, "a:off")
+    ext <- xml_child(node_xfrm, "a:ext")
+    chOff <- xml_child(node_xfrm, "a:chOff")
+    chExt <- xml_child(node_xfrm, "a:chExt")
+    xml_attr( off, "x") <- sprintf( "%.0f", location$left*914400 )
+    xml_attr( off, "y") <- sprintf( "%.0f", location$top*914400 )
+    xml_attr( ext, "cx") <- sprintf( "%.0f", location$width*914400 )
+    xml_attr( ext, "cy") <- sprintf( "%.0f", location$height*914400 )
+    xml_attr( chOff, "x") <- sprintf( "%.0f", location$left*914400 )
+    xml_attr( chOff, "y") <- sprintf( "%.0f", location$top*914400 )
+    xml_attr( chExt, "cx") <- sprintf( "%.0f", location$width*914400 )
+    xml_attr( chExt, "cy") <- sprintf( "%.0f", location$height*914400 )
+
+    # add location$rotation to cNvPr:name
+    if( !is.null(location$rotation) && is.numeric(location$rotation) ) {
+      xml_set_attr(node_xfrm, "rot", sprintf("%.0f", -location$rotation * 60000))
+    }
+  }
+
+  if( !inherits(node_sppr, "xml_missing") ){
+    # add location$bg to SpPr
+    if( !is.null(location$bg) ) {
+      bg_str <- gen_bg_str(location$bg)
+      xml_add_child(node_sppr, as_xml_document(bg_str))
+    }
+  }
+  value
+}
 
 #' @export
-#' @section with xml_document:
-#' When value is an xml_document object, its content will be
-#' added as a new shape in the current slide. This function
-#' is to be used to add custom openxml code.
-#' @rdname ph_with
+#' @importFrom xml2 xml_child xml_set_attr xml_missing
+#' @describeIn ph_with add an xml_document object to a new shape on the
+#' current slide. This function is to be used to add custom openxml code.
 ph_with.xml_document <- function( x, value, location, ... ){
   slide <- x$slide$get_slide(x$cursor)
 
-  location <- location_eval(rlang::enquo(location), x)
-  node <- xml_find_first( value, as_xpath_content_sel("//") )
-  node <- set_xfrm_attr(node, offx = location$left*914400, offy = location$top*914400,
-                        cx = location$width*914400, cy = location$height*914400)
+  location <- fortify_location(location, doc = x)
+
+  xml_to_slide(slide, location, value)
+
   xml_add_child(xml_find_first(slide$get(), "//p:spTree"), value)
 
   slide$fortify_id()
   x
 }
 
+# old functions -----------
+
 #' @export
 #' @title add an xml string as new shape
 #' @description Add an xml string as new shape in the current slide. This function
@@ -570,9 +563,6 @@ ph_from_xml_at <- function( x, value, left, top, width, height ){
   x
 }
 
-
-# old functions -----------
-
 #' @export
 #' @title add text into a new shape
 #' @description add text into a new shape in a slide.
@@ -581,18 +571,29 @@ ph_from_xml_at <- function( x, value, left, top, width, height ){
 #' @inheritParams ph_empty
 #' @param str text to add
 #' @examples
-#' fileout <- tempfile(fileext = ".pptx")
+#' # define locations for placeholders ----
+#' loc_title <- ph_location_type(type = "title")
+#' loc_footer <- ph_location_type(type = "ftr")
+#' loc_dt <- ph_location_type(type = "dt")
+#' loc_slidenum <- ph_location_type(type = "sldNum")
+#' loc_body <- ph_location_type(type = "body")
+#'
+#'
 #' doc <- read_pptx()
-#' doc <- add_slide(doc, layout = "Title and Content", master = "Office Theme")
-#' doc <- ph_with_text(x = doc, type = "title", str = "Un titre")
-#' doc <- ph_with_text(x = doc, type = "ftr", str = "pied de page")
-#' doc <- ph_with_text(x = doc, type = "dt", str = format(Sys.Date()))
-#' doc <- ph_with_text(x = doc, type = "sldNum", str = "slide 1")
+#' doc <- add_slide(doc)
+#' doc <- ph_with(x = doc, "Un titre", location = loc_title)
+#' doc <- ph_with(x = doc, "pied de page", location = loc_footer)
+#' doc <- ph_with(x = doc, format(Sys.Date()), location = loc_dt)
+#' doc <- ph_with(x = doc, "slide 1", location = loc_slidenum)
+#' doc <- ph_with(x = doc, letters[1:10], location = loc_body)
 #'
+#' loc_subtitle <- ph_location_type(type = "subTitle")
+#' loc_ctrtitle <- ph_location_type(type = "ctrTitle")
 #' doc <- add_slide(doc, layout = "Title Slide", master = "Office Theme")
-#' doc <- ph_with_text(x = doc, type = "subTitle", str = "Un sous titre")
-#' doc <- ph_with_text(x = doc, type = "ctrTitle", str = "Un titre")
+#' doc <- ph_with(x = doc, "Un sous titre", location = loc_subtitle)
+#' doc <- ph_with(x = doc, "Un titre", location = loc_ctrtitle)
 #'
+#' fileout <- tempfile(fileext = ".pptx")
 #' print(doc, target = fileout )
 #' @importFrom xml2 xml_find_first as_xml_document xml_remove
 #' @inherit ph_empty seealso
@@ -600,15 +601,10 @@ ph_with_text <- function( x, str, type = "title", index = 1, location = NULL ){
 
   if(!is.character(str))
     str <- format(str)
-
-  if( !is.null( rlang::get_expr(rlang::enquo(location)) ) ){
-    ph_with(x, external_img(src=src, width = width, height = height), location = !!rlang::enexpr( location ))
-  } else {
-    slide <- x$slide$get_slide(x$cursor)
-    sh_pr_df <- slide$get_location(type = type, index = index)
-    ph_with(x, str, location = ph_location(ph = sh_pr_df$ph, label = sh_pr_df$ph_label, left = sh_pr_df$left, top = sh_pr_df$top,
-                                           width = sh_pr_df$width, height = sh_pr_df$height))
+  if( is.null( location ) ){
+    location <- ph_location_type(type = type, id = index)
   }
+  ph_with(x, str, location = location)
 }
 
 
@@ -621,35 +617,20 @@ ph_with_text <- function( x, str, type = "title", index = 1, location = NULL ){
 #' @param value data.frame
 #' @param header display header if TRUE
 #' @param first_row,last_row,first_column,last_column logical for PowerPoint table options
-#' @examples
-#' library(magrittr)
-#'
-#' doc <- read_pptx() %>%
-#'   add_slide(layout = "Title and Content", master = "Office Theme") %>%
-#'   ph_with_table(value = mtcars[1:6,], type = "body",
-#'     last_row = FALSE, last_column = FALSE, first_row = TRUE)
-#'
-#' print(doc, target = tempfile(fileext = ".pptx"))
 ph_with_table <- function( x, value, type = "body", index = 1,
                            header = TRUE,
                            first_row = TRUE, first_column = FALSE,
                            last_row = FALSE, last_column = FALSE,
                            location = NULL ){
+  .Deprecated(new = "ph_with")
   stopifnot(is.data.frame(value))
 
-  if( !is.null( rlang::get_expr(rlang::enquo(location)) ) ){
-    ph_with(x, value, location = !!rlang::enexpr( location ), header = header,
-            first_row = first_row, first_column = first_column,
-            last_row = last_row, last_column = last_column)
-  } else {
-    slide <- x$slide$get_slide(x$cursor)
-    sh_pr_df <- slide$get_location(type = type, index = index)
-    ph_with(x, value, location = ph_location(ph = sh_pr_df$ph, label = sh_pr_df$ph_label, left = sh_pr_df$left, top = sh_pr_df$top,
-                                             width = sh_pr_df$width, height = sh_pr_df$height),
-            header = header,
-            first_row = first_row, first_column = first_column,
-            last_row = last_row, last_column = last_column)
+  if( is.null( location ) ){
+    location <- ph_location_type(type = type, id = index)
   }
+  ph_with(x, value, location = location, header = header,
+          first_row = first_row, first_column = first_column,
+          last_row = last_row, last_column = last_column)
 }
 
 
@@ -662,33 +643,15 @@ ph_with_table <- function( x, value, type = "body", index = 1,
 #' @inheritParams ph_empty
 #' @param src image filename, the basename of the file must not contain any blank.
 #' @param width,height image size in inches
-#' @examples
-#' fileout <- tempfile(fileext = ".pptx")
-#' doc <- read_pptx()
-#' doc <- add_slide(doc, layout = "Title and Content", master = "Office Theme")
-#'
-#' img.file <- file.path( R.home("doc"), "html", "logo.jpg" )
-#' if( file.exists(img.file) ){
-#'   doc <- ph_with_img(x = doc, type = "body", src = img.file, height = 1.06, width = 1.39 )
-#' }
-#'
-#' print(doc, target = fileout )
 #' @importFrom xml2 xml_find_first as_xml_document xml_remove
 ph_with_img <- function( x, src, type = "body", index = 1,
                          width = NULL, height = NULL,
                          location = NULL ){
-
-  if( !is.null( rlang::get_expr(rlang::enquo(location)) ) )
-    ph_with(x, external_img(src=src, width = width, height = height), location = !!rlang::enexpr( location ))
-  else {
-    slide <- x$slide$get_slide(x$cursor)
-    sh_pr_df <- slide$get_location(type = type, index = index)
-    if( is.null( width ) ) width <- sh_pr_df$width
-    if( is.null( height ) ) height <- sh_pr_df$height
-    ph_with(x, external_img(src=src, width = width, height = height),
-            location = ph_location(ph = sh_pr_df$ph, label = sh_pr_df$ph_label, left = sh_pr_df$left, top = sh_pr_df$top,
-                                   width = width, height = height))
+  .Deprecated(new = "ph_with")
+  if( is.null( location ) ){
+    location <- ph_location_type(type = type, id = index)
   }
+  ph_with(x, external_img(src=src, width = width, height = height), location = location)
 }
 
 #' @export
@@ -701,38 +664,15 @@ ph_with_img <- function( x, src, type = "body", index = 1,
 #' @param width,height image size in inches
 #' @param ... Arguments to be passed to png function.
 #' @importFrom grDevices png dev.off
-#' @examples
-#' if( require("ggplot2") ){
-#'   doc <- read_pptx()
-#'   doc <- add_slide(doc, layout = "Title and Content",
-#'     master = "Office Theme")
-#'
-#'   gg_plot <- ggplot(data = iris ) +
-#'     geom_point(mapping = aes(Sepal.Length, Petal.Length), size = 3) +
-#'     theme_minimal()
-#'
-#'   if( capabilities(what = "png") ){
-#'     doc <- ph_with_gg(doc, value = gg_plot )
-#'     doc <- ph_with_gg_at(doc, value = gg_plot,
-#'       height = 4, width = 8, left = 4, top = 4 )
-#'   }
-#'
-#'   print(doc, target = tempfile(fileext = ".pptx"))
-#' }
 ph_with_gg <- function( x, value, type = "body", index = 1,
                         width = NULL, height = NULL, location = NULL, ... ){
-
-
-  if( !is.null( rlang::get_expr(rlang::enquo(location)) ) )
-    ph_with(x, value, location = !!rlang::enexpr( location ))
-  else {
-    slide <- x$slide$get_slide(x$cursor)
-    sh_pr_df <- slide$get_location(type = type, index = index)
-    if( is.null( width ) ) width <- sh_pr_df$width
-    if( is.null( height ) ) height <- sh_pr_df$height
-    ph_with(x, value, location = ph_location(ph = sh_pr_df$ph, label = sh_pr_df$ph_label, left = sh_pr_df$left, top = sh_pr_df$top,
-                                             width = width, height = height))
+  .Deprecated(new = "ph_with")
+  if( is.null( location ) ){
+    location <- ph_location_type(type = type, id = index)
+    if( !is.null( width ) ) location$width <- width
+    if( !is.null( height ) ) location$height <- height
   }
+  ph_with(x, value, location = location)
 
 }
 
@@ -749,34 +689,19 @@ ph_with_gg <- function( x, value, type = "body", index = 1,
 #' single \code{fp_text} objects. Use \code{fp_text(font.size = 0, ...)} to
 #' inherit from default sizes of the presentation.
 #' @export
-#' @examples
-#' library(magrittr)
-#' pptx <- read_pptx()
-#' pptx <- add_slide(x = pptx, layout = "Title and Content", master = "Office Theme")
-#' pptx <- ph_with_text(x = pptx, type = "title", str = "Example title")
-#' pptx <- ph_with_ul(
-#'   x = pptx, location = ph_location_type(type="body"),
-#'   str_list = c("Level1", "Level2", "Level2", "Level3", "Level3", "Level1"),
-#'   level_list = c(1, 2, 2, 3, 3, 1),
-#'   style = fp_text(color = "red", font.size = 0) )
-#' print(pptx, target = tempfile(fileext = ".pptx"))
 ph_with_ul <- function(x, type = "body", index = 1,
                        str_list = character(0), level_list = integer(0),
                        style = NULL,
                        location = NULL) {
+  .Deprecated(new = "ph_with")
   value <- unordered_list(
     level_list = level_list,
     str_list = str_list,
     style = style )
-
-  if( !is.null( rlang::get_expr(rlang::enquo(location)) ) ){
-    ph_with(x = x, value = value, location = !!rlang::enexpr( location ) )
-  } else {
-    slide <- x$slide$get_slide(x$cursor)
-    sh_pr_df <- slide$get_location(type = type, index = index)
-    ph_with(x, value, location = ph_location(ph = sh_pr_df$ph, label = sh_pr_df$ph_label, left = sh_pr_df$left, top = sh_pr_df$top,
-                                             width = sh_pr_df$width, height = sh_pr_df$height))
+  if( is.null( location ) ){
+    location <- ph_location_type(type = type, id = index)
   }
+  ph_with(x = x, value = value, location = location )
 }
 
 
@@ -795,42 +720,12 @@ ph_with_ul <- function(x, type = "body", index = 1,
 #' @param template_index placeholder template index (integer). To be used when a placeholder
 #' template type is not unique in the current slide, e.g. two placeholders with
 #' type 'body'.
-#' @examples
-#'
-#' # demo ph_empty_at ------
-#' fileout <- tempfile(fileext = ".pptx")
-#' doc <- read_pptx()
-#' doc <- add_slide(doc, layout = "Title and Content", master = "Office Theme")
-#' doc <- ph_empty_at(x = doc, left = 1, top = 2, width = 5, height = 4)
-#'
-#' print(doc, target = fileout )
 ph_empty_at <- function( x, left, top, width, height, bg = "transparent", rot = 0,
                          template_type = NULL, template_index = 1 ){
-
-  ph <- NA_character_
-  label <- ""
-  type <- "body"
-  slide <- x$slide$get_slide(x$cursor)
-
-  if( !is.null( template_type ) ){
-    xfrm_df <- slide$get_xfrm(type = template_type, index = template_index)
-    ph <- xfrm_df$ph
-  } else {
-    ph <- sprintf('<p:ph type="%s"/>', type)
-  }
-  new_ph <- gen_ph_str_old(left = left, top = top,
-                           width = width, height = height,
-                           label = "", ph = ph,
-                           rot = rot, bg = bg)
-
-
-  xml_elt <- paste0( pml_with_ns("p:sp"), new_ph, "</p:sp>" )
-  node <- as_xml_document(xml_elt)
-
-  xml_add_child(xml_find_first(slide$get(), "//p:spTree"), node)
-  slide$fortify_id()
-  x
-
+  .Deprecated(new = "ph_with")
+  location <- ph_location_template(left = left, top = top, width = width, height = height,
+              label = "", type = template_type, id = template_index)
+  ph_with(x, "", location = location)
 }
 
 
@@ -838,23 +733,10 @@ ph_empty_at <- function( x, left, top, width, height, bg = "transparent", rot =
 #' @rdname ph_with_img
 #' @param left,top location of the new shape on the slide
 #' @param rot rotation angle
-#' @examples
-#'
-#' fileout <- tempfile(fileext = ".pptx")
-#' doc <- read_pptx()
-#' doc <- add_slide(doc, layout = "Title and Content", master = "Office Theme")
-#'
-#' img.file <- file.path( R.home("doc"), "html", "logo.jpg" )
-#' if( file.exists(img.file) ){
-#'   doc <- ph_with_img_at(x = doc, src = img.file, height = 1.06, width = 1.39,
-#'     left = 4, top = 4, rot = 45 )
-#' }
-#'
-#' print(doc, target = fileout )
 ph_with_img_at <- function( x, src, left, top, width, height, rot = 0 ){
 
   ph_with(x, external_img(src=src, width = width, height = height),
-          location = ph_location(ph = "", label = "", left = left, top = top, width = width, height = height))
+          location = ph_location(ph = "", label = "", left = left, top = top, width = width, height = height, rotation = rot))
 
 }
 
@@ -862,22 +744,12 @@ ph_with_img_at <- function( x, src, left, top, width, height, rot = 0 ){
 #' @rdname ph_with_table
 #' @param left,top location of the new shape on the slide
 #' @param width,height shape size in inches
-#' @examples
-#'
-#' library(magrittr)
-#'
-#' doc <- read_pptx() %>%
-#'   add_slide(layout = "Title and Content", master = "Office Theme") %>%
-#'   ph_with_table_at(value = mtcars[1:6,],
-#'     height = 4, width = 8, left = 4, top = 4,
-#'     last_row = FALSE, last_column = FALSE, first_row = TRUE)
-#'
-#' print(doc, target = tempfile(fileext = ".pptx"))
 ph_with_table_at <- function( x, value, left, top, width, height,
                               header = TRUE,
                               first_row = TRUE, first_column = FALSE,
                               last_row = FALSE, last_column = FALSE ){
 
+  .Deprecated(new = "ph_with")
   stopifnot(is.data.frame(value))
   ph_with(x,
           value,
@@ -929,36 +801,11 @@ ph_with_gg_at <- function( x, value, width, height, left, top, ... ){
 #' @param template_index placeholder template index (integer). To be used when a placeholder
 #' template type is not unique in the current slide, e.g. two placeholders with
 #' type 'body'.
-#' @examples
-#'
-#' fileout <- tempfile(fileext = ".pptx")
-#' doc <- read_pptx()
-#' doc <- add_slide(doc, layout = "Title and Content",
-#'   master = "Office Theme")
-#'
-#' bold_face <- shortcuts$fp_bold(font.size = 0)
-#' bold_redface <- update(bold_face, color = "red")
-#'
-#' fpar_1 <- fpar(
-#'   ftext("Hello ", prop = bold_face), ftext("World", prop = bold_redface ),
-#'   ftext(", \r\nhow are you?", prop = bold_face ) )
-#'
-#' fpar_2 <- fpar(
-#'   ftext("Hello ", prop = bold_face), ftext("World", prop = bold_redface ),
-#'   ftext(", \r\nhow are you again?", prop = bold_face ) )
-#'
-#' doc <- ph_with_fpars_at(x = doc, fpars = list(fpar_1, fpar_2),
-#'   fp_pars = list(NULL, fp_par(text.align = "center")),
-#'   left = 1, top = 2, width = 7, height = 4)
-#' doc <- ph_with_fpars_at(x = doc, fpars = list(fpar_1, fpar_2),
-#'   template_type = "body", template_index = 1,
-#'   left = 4, top = 5, width = 4, height = 3)
-#'
-#' print(doc, target = fileout )
 ph_with_fpars_at <- function( x, fpars = list(), fp_pars = list(),
                               left, top, width, height, bg = "transparent", rot = 0,
                               template_type = NULL, template_index = 1 ){
 
+  .Deprecated(new = "ph_with")
   if( length(fp_pars) < 1 )
     fp_pars <- lapply(fpars, function(x) NULL )
   if( length(fp_pars) != length(fpars) )
@@ -974,20 +821,9 @@ ph_with_fpars_at <- function( x, fpars = list(), fp_pars = list(),
     fpar = fpars, fp_par = fp_pars, SIMPLIFY = FALSE )
   p_ <- do.call(block_list, p_)
 
-  ph <- ""
-  label <- ""
-  if( !is.null( template_type ) ){
-    slide <- x$slide$get_slide(x$cursor)
-    xfrm_df <- slide$get_xfrm(type = template_type, index = template_index)
-    ph <- xfrm_df$ph
-    label <- xfrm_df$ph_label
-  }
-
-  ph_with(x, p_,
-          location = ph_location(
-            ph = ph, label = label, left = left, top = top,
-            width = width, height = height))
-
+  location <- ph_location_template(left = left, top = top, width = width, height = height,
+                                   label = "", type = template_type, id = template_index)
+  ph_with(x, p_, location = location)
 }
 
 
