@@ -156,29 +156,6 @@ read_theme_colors <- function(doc, theme){
 }
 
 
-get_shape_id <- function(x, type = NULL, id_chr = NULL ){
-  shape_index_data <- slide_summary(x)
-  shape_index_data$shape_id <- seq_len(nrow(shape_index_data))
-
-  if( !is.null(type) && !is.null(id_chr) ){
-    filter_v <- shape_index_data$type == type & shape_index_data$id == id_chr
-    shape_index_data <- shape_index_data[filter_v,]
-  } else if( is.null(type) && !is.null(id_chr) ){
-    filter_v <- shape_index_data$id == id_chr
-    shape_index_data <- shape_index_data[filter_v,]
-  } else if( !is.null(type) ){
-    filter_v <- shape_index_data$type == type
-    shape_index_data <- shape_index_data[filter_v,]
-  }
-
-  if( nrow(shape_index_data) < 1 )
-    stop("selection does not match any row in slide_summary. Use function slide_summary.", call. = FALSE)
-  else if( nrow(shape_index_data) > 1 )
-    stop("selection does match more than a single row in slide_summary. Use function slide_summary.", call. = FALSE)
-
-  shape_index_data$shape_id
-}
-
 
 characterise_df <- function(x){
   names(x) <- htmlEscape(names(x))
@@ -209,10 +186,11 @@ simple_lag <- function( x, default=0 ){
 }
 
 rbind.match.columns <- function(list_df) {
-  col <- unique(unlist(sapply(list_df, names)))
 
+  col <- unique(unlist(lapply(list_df, colnames)))
+  list_df <- Filter(function(x) nrow(x)>0, list_df)
   list_df <- lapply(list_df, function(x, col) {
-    x[, setdiff(col, names(x))] <- NA
+    x[, setdiff(col, colnames(x))] <- NA
     x
   }, col = col)
   do.call(rbind, list_df)
