@@ -3,7 +3,7 @@ context("table in pptx")
 test_that("ph_with_table", {
   x <- read_pptx()
   x <- add_slide(x, "Title and Content", master = "Office Theme")
-  x <- ph_with_table(x, value = iris, type = "body")
+  x <- ph_with(x, value = iris, location = ph_location_type(type = "body"))
   xmldoc <- x$slide$get_slide(1)$get()
   xml_tab <- xml_find_all(xmldoc, xpath = "p:cSld/p:spTree/p:graphicFrame/a:graphic/a:graphicData/a:tbl")
   expect_false( inherits(xml_tab, "xml_missing") )
@@ -12,7 +12,7 @@ test_that("ph_with_table", {
 test_that("pml structure", {
   x <- read_pptx()
   x <- add_slide(x, "Title and Content", master = "Office Theme")
-  x <- ph_with_table(x, value = mtcars, type = "body")
+  x <- ph_with(x, value = mtcars, location = ph_location_type(type = "body"))
   xmldoc <- x$slide$get_slide(1)$get()
 
   xml_tr <- xml_find_all(xmldoc, xpath = "p:cSld/p:spTree/p:graphicFrame/a:graphic/a:graphicData/a:tbl/a:tr")
